<?php

namespace App\Http\Controllers;

use App\Models\Approval;
use App\Models\Employee;
use App\Models\Positionbyproject;
use App\Models\Project;
use App\Models\User;
use Illuminate\Http\Request;
use App\Notifications\ApprovalNotification;
use App\Notifications\RejectNotification;
use Illuminate\Support\Facades\Notification;

class ApprovalController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        return $this->middleware('auth:web');
    }

    public function sendNotif($data, $notif_email=''){

        $approval = new Approval;
        $approval->project_id   = $data['project_id'];
        $approval->status       = $data['status'];
        $approval->reason       = $data['reason'];
        $approval->approval_by  = $data['approval_id'];
        $approval->approval_name    = $data['project_nama'];
        $approval->approval_jabatan = $data['project_jabatan'];
        $approval->save();
        
        Notification::send($data['user'], new ApprovalNotification($data['project'],$data['project_name'], $data['status'], $data['type'],$data['user'],$data['created']));

    }

    public function needapprovalmanager(Request $request,$id)
    {
        $project = Project::findOrFail(decrypt($id));
 
        if($project->status == 'draft' or ($project->status == 'Project rejected by Manager' or $project->status == 'Project rejected by VP') !== false){
            $getmanager = Positionbyproject::where('project_id',decrypt($id))->select('email_pm')->first();
    
            $status = 'Waiting for project manager approval';
        
            $project->step  = 2;
            $project->status  = $status;
            $project->send_approved_date  = now();
            $project->save();
    
 
            $created = User::leftJoin('projects','users.id','projects.created_by')
            ->select('users.id','users.name','users.email')
            ->first();
    
            //getmanager
            
            $users = User::leftJoin('employees','users.id','employees.user_id')
                ->where('users.email', $project->project_manager)           
                ->select('users.id','employees.name','users.email')
                ->first();
    
        
            $data['project_id'] = $project->id;
            $data['project'] = $project;
            $data['project_name'] = $project->project_name;
            $data['status'] = $project->status;
            $data['reason'] = $project->status;
            $data['type'] = 'Staf';
            $data['created'] = $project->employee;
     
            
            
    
            // notif user manager
            if(!empty($users)){
                $data['user'] = $users;
                $data['approval_id'] = $users->id;
                $data['project_nama'] = $users->name;
                $data['project_jabatan'] = 'Project Manager';
                $this->sendNotif($data);
            }
    
           
        }
        
        
      


        return redirect()->route('project.index')->with('success', 'manager approval process');
      

        
    }

    public function needapprovalvp(Request $request,$id)
    {
        $project = Project::findOrFail(decrypt($id));
 
        if ($project->status == 'Waiting for project manager approval') {
            $getmanager = Positionbyproject::where('project_id',decrypt($id))->select('email_po')->first();

            $status = 'Waiting for project owner approval';

            $project->step  = 3;
            $project->date_approved_manager = now();
            $project->status  = $status;
            $project->save();

            


            //getusercreated
            $created = User::leftJoin('projects','users.id','projects.created_by')
            ->select('users.id','users.name','users.email')
            ->first();
    
            //getmanager
            
            $users = User::leftJoin('employees','users.id','employees.user_id')
                ->where('users.email', $project->project_owner)           
                ->select('users.id','employees.name','users.email')
                ->first();
            


                $data['project_id'] = $project->id;
                $data['project'] = $project;
                $data['project_name'] = $project->project_name;
                $data['status'] = $status;
                $data['reason'] = $project->status;
                $data['type'] = 'Manager';
                $data['created'] = $project->employee;

                



                // notif user VP
                if(!empty($users)){
                    $data['user'] = $users;
                    $data['approval_id'] = $users->id;
                    $data['project_nama'] = $users->nama;
                    $data['project_jabatan'] = $users->jabatan;
                    $this->sendNotif($data);
                }

            // }
        }
        
        return redirect()->route('project.index')->with('success', 'vp approval process');


        
    }

    public function approvedvp(Request $request,$id)
    {
        $project = Project::findOrFail(decrypt($id));
 
        if ($project->status == 'Waiting for project owner approval') {
            $jabatan = $project->employee->jabatanid;
            $jbtn = substr($jabatan,-10,-3);

            $status = 'ProjectOwnerApproved';           

            $project->step  = 4;
            $project->date_approved_vp = now();
            $project->status  = $status;
            $project->save();
            
            //getusercreated
            $created = User::leftJoin('projects','users.id','projects.created_by')
            ->select('users.id','users.name','users.email')
            ->first();
    
            //getmanager
            
            $users = User::leftJoin('employees','users.id','employees.user_id')
                ->where('users.email', $project->project_manager)           
                ->select('users.id','employees.name','users.email')
                ->first();

            // dd($jbtn,$user);
        

            // if ($project->status == 'ProjectOwnerApproved') { 
                $data['project_id'] = $project->id;
                $data['project'] = $project;
                $data['project_name'] = $project->project_name;
                $data['status'] = $status;
                $data['reason'] = $status;
                $data['type'] = 'VP';
                $data['created'] = $project->employee;

                
                // notif user created
                $data['user'] = $created;
                $data['approval_id'] = $created->id;
                $data['project_nama'] = $created->nama;
                $data['project_jabatan'] = $created->jabatan;
                $this->sendNotif($data);



                // notif user manager
            if(!empty($users)){
                $data['user'] = $users;
                $data['approval_id'] = $users->id;
                $data['project_nama'] = $users->nama;
                $data['project_jabatan'] = $users->jabatan;
                $this->sendNotif($data);
            }

                // notif user member
                if(!empty($project->team_member)){
                    $members = User::leftJoin('employees','users.id','employees.user_id')
                        ->whereIn('users.email', explode(',',$project->team_member))           
                        ->select('users.id','employees.name','users.email')
                        ->get();
                    if(!empty($members)){
                        foreach($members as $member){
                            $data['user'] = $member;
                            $data['approval_id'] = $member->id;
                            $data['project_nama'] = $member->name;
                            $data['project_jabatan'] = 'Team Member';
                            $this->sendNotif($data);
                        }
                    }
                }
                

        }

       

        
        return redirect()->route('project.index')->with('success', 'Project Approved');


        
    }

    public function rejectedbymgr(Request $request,$id)
    {
        $project = Project::findOrFail(decrypt($id));
 
        if($project->status == 'Waiting for project manager approval') {
            $getmanager = Positionbyproject::where('project_id',decrypt($id))->select('email_pm')->first();
    

            $status = 'Project rejected by Manager';
  
    
            $project->step  = 5;
            $project->date_rejected_manager = now();
            $project->reason_rejected = $request->reason_rejected;
            $project->status  = $status;
            $project->save();

    
            // notif user manager
            if(!empty($users)){
                $data['user'] = $users;
                $data['approval_id'] = $users->id;
                $data['project_nama'] = $users->name;
                $data['project_jabatan'] = 'Project Manager';
                $this->sendNotif($data);
            }
    


            $created = User::leftJoin('projects','users.id','projects.created_by')
            ->select('users.id','users.name','users.email')
            ->first();

            //getmanager
            
            $users = User::leftJoin('employees','users.id','employees.user_id')
                ->where('users.email', $project->project_manager)           
                ->select('users.id','employees.name','users.email')
                ->first();
    
 
            
            // if ($project->status == 'Project ditolak Manager') {  
                $data['project_id'] = $project->id;
                $data['project'] = $project;
                $data['project_name'] = $project->project_name;
                $data['status'] = $status;
                $data['reason'] = $request->reason_rejected;
                $data['type'] = 'Manager';
                $data['created'] = $project->employee;

                
                // notif user created
                $data['user'] = $created;
                $data['approval_id'] = $created->id;
                $data['project_nama'] = $created->name;
                $data['project_jabatan'] = $created->jabatan;
                $this->sendNotif($data);
    
                // notif user manager
                $data['user'] = $users;
                $data['approval_id'] = $users->id;
                $data['project_nama'] = $users->name;
                $data['project_jabatan'] = $users->jabatan;
                $this->sendNotif($data);
    

    
            // }
        }
        
       
        return redirect()->route('project.index')->with('error', 'Rejected');
      

        
    }

    public function rejectedbyvp(Request $request,$id)
    {
        $project = Project::findOrFail(decrypt($id));
 
        if($project->status == 'Waiting for project owner approval') {
            $getmanager = Positionbyproject::where('project_id',decrypt($id))->select('email_po')->first();


            $status = 'Project rejected by VP';


            $project->step  = 6;
            $project->date_rejected_vp = now();

            $project->status  = $status;
            $project->save();

            $reasonrejected = Project::where('id',decrypt($id))->update([
                'reason_rejected'    => $request->reason_rejected,
            ]);


            $created = User::leftJoin('projects','users.id','projects.created_by')
            ->select('users.id','users.name','users.email')
            ->first();
            
            $users = User::leftJoin('employees','users.id','employees.user_id')
                ->where('users.email', $project->project_owner)           
                ->select('users.id','employees.name','users.email')
                ->first();
    
            

            
            // if ($project->status == 'Project ditolak VP') {  
                $data['project_id'] = $project->id;
                $data['project'] = $project;
                $data['project_name'] = $project->project_name;
                $data['status'] = $status;
                $data['reason'] = $request->reason_rejected;
                $data['type'] = 'VP';
                $data['created'] = $project->employee;

                
                // notif user created
                $data['user'] = $created;
                $data['approval_id'] = $created->id;
                $data['project_nama'] = $created->name;
                $data['project_jabatan'] = $created->jabatan;
                $this->sendNotif($data);

                // notif manager & Owner
                foreach($users as $user){
                    $data['user'] = $user;
                    $data['approval_id'] = $user->id;
                    $data['project_nama'] = $user->name;
                    $data['project_jabatan'] = $user->jabatan;
                    $this->sendNotif($data);
                }



            // }
        }
    
        return redirect()->route('project.index')->with('error', 'Rejected');


        
    }

}
