<?php

namespace App\Http\Controllers;

use App\Models\ActualGanttTask;
use App\Models\Approval;
use App\Models\Employee;
use App\Models\GanttCode;
use App\Models\GanttTask;
use App\Models\GroupTag;
use App\Models\Portofolio;
use App\Models\Positionbyproject;
use App\Models\Project;
use App\Models\RefDivisi;
use App\Models\Series;
use App\Models\User;
use App\Models\Wbs;
use App\Models\WbsLink;
use App\Notifications\ApprovalNotification;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use File;
use Illuminate\Support\Facades\DB;
use PDF;
use Illuminate\Support\Facades\Notification;
// use Illuminate\Notifications\Notification;
use Illuminate\Support\Facades\Notification as FacadesNotification;

class ProjectController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        return $this->middleware('auth:web');
        
    }

    public function index(Request $request)
    {
        $getyear = $request->tahun;

        $cekuserlogin = Auth::user()->employee;

        
        
    

            if(!empty($getyear))
            {

        
                $project = Project::where(function ($w) use ($cekuserlogin) {
                    $w->where('project_manager', $cekuserlogin->email)
                        ->orWhere('project_owner', $cekuserlogin->email)
                        ->orWhere(function ($q) use ($cekuserlogin) {
                            $q->whereIn('team_member', [$cekuserlogin->email])
                              ->orWhere('team_member', 'LIKE', '%' . $cekuserlogin->email . '%');
                        })
                        ->orWhere('created_by', $cekuserlogin->user_id);
                })
                ->whereYear('created_at', $getyear)
                ->orderBy('created_at', 'DESC')
                ->get();
            }   
            else{

             
                $project = Project::where(function ($w) use ($cekuserlogin) {
                    $w->where('project_manager', $cekuserlogin->email)
                        ->orWhere('project_owner', $cekuserlogin->email)
                        ->orWhere(function ($q) use ($cekuserlogin) {
                            $q->whereIn('team_member', [$cekuserlogin->email])
                              ->orWhere('team_member', 'LIKE', '%' . $cekuserlogin->email . '%');
                        })
                        ->orWhere('created_by', $cekuserlogin->user_id);
                })
                ->orderBy('created_at', 'DESC')
                ->get();
            }         
        
        return view('admin.manage_project.index', compact('project'));
    }

    public function registeredproject(Request $request)
    {
        
        $getyear = $request->tahun;

        
            
        $cekuserlogin = Auth::user()->employee;
        
        
        
       

        if(!empty($getyear))
        {
            
            
            $project = Project::where(function ($w) use ($cekuserlogin) {
                $w->where('project_manager', $cekuserlogin->sso_email)
                    ->orWhere('project_owner', $cekuserlogin->sso_email)
                    ->orWhere(function ($q) use ($cekuserlogin) {
                        $q->whereIn('team_member', [$cekuserlogin->sso_email])
                          ->orWhere('team_member', 'LIKE', '%' . $cekuserlogin->sso_email . '%');
                    })
                    ->orWhere('created_by', $cekuserlogin->user_id);
            })
            ->whereYear('created_at', $getyear)
            ->orderBy('created_at', 'DESC')
            ->get();
        }
        else{
        
      
        $project = Project::where(function ($w) use ($cekuserlogin) {
            $w->where('project_manager', $cekuserlogin->sso_email)
                ->orWhere('project_owner', $cekuserlogin->sso_email)
                ->orWhere(function ($q) use ($cekuserlogin) {
                    $q->whereIn('team_member', [$cekuserlogin->sso_email])
                      ->orWhere('team_member', 'LIKE', '%' . $cekuserlogin->sso_email . '%');
                })
                ->orWhere('created_by', $cekuserlogin->user_id);
        })
        ->orderBy('created_at', 'DESC')
        ->get();
        }
        

       

        return view('admin.manage_project.registeredproject', compact('project'));    
    }

    public function downloadpdf($id)
    {
        $project = Project::findOrFail(decrypt($id));
        $app_date = Approval::where('project_id',decrypt($id))->where('status','Disetujui VP')->groupBy('project_id')->get();
        
        $pdf = PDF::loadview('admin.manage_project.project_pdf',['project'=>$project]);
    	return $pdf->download('Project Information.pdf');
    }

    public function seepdf($id)
    {
        $project = Project::findOrFail(decrypt($id));
        $powner = Project::where('id',decrypt($id))->select('project_owner')->pluck('project_owner');
        // dd($powner);
        $gt = GroupTag::get();
        $projectowner = Employee::where('sso_email',$powner)->select('jabatan')->first();
                        // dd($projectowner);
        return view('admin.manage_project.project_pdf',compact('project','gt'));
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        
        $employee = Employee::orderBy('name', 'asc')->get();
        $portofolio = Portofolio::get();
        $gt = GroupTag::get();
        $series = Series::first();
        return view('admin.manage_project.create', compact('employee', 'portofolio', 'gt', 'series'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $validateData= $request->validate(
            [                               
                'portofolio'    =>  'required',
                'project_name'  => 'required',
                'project_description'   => 'required',
                'project_owner' => 'required',
                'project_manager'   => 'required',
                'project_doc'   => 'required|mimes:png,jpg,jpeg,pdf,doc,docs,xls,xlsx,ppt,pptx|max:10000',
                'investasi' => 'required',
                'cost'  => 'required',
                'start_date'    => 'required',
                'end_date'  => 'required',
            ],
            [
                'portofolio.required'   => 'Portofolio wajib diisi!',
                'project_name.required' => 'Project Name Wajib diisi!',
                'project_description.required'  => 'Project Description Wajib Diisi!',
                'project_owner.required'    => 'Project Owner Wajib Diisi',
                'project_manager.required'  => 'Project Manager Wajib diisi',
                'project_doc.required'       => "Project Document Wajib Diisi!",
                'project.max'   =>  "Max ukuran file adalah 10mb",
                'investasi.required' => 'Nilai Investasi Tidak Boleh Kosong',
                'cost.required' => 'Nilai Cost Tidak Boleh Kosong',
                'start_date' => 'Tanggal Mulai Tidak Boleh Kosong',
                'end_date' => 'Tanggal Berakhir Tidak Boleh Kosong',
            ]);
// dd($request->input());
        if ($request->file('project_doc')) {
            $file = $request->file('project_doc');
            $filename = md5($file->getClientOriginalName()) . uniqid() . '.' . $file->getClientOriginalExtension();
            // $filename = 'Project_Doc'.'-'.$file->getClientOriginalName();
            $file->move(public_path('storage/app/public/project_doc'), $filename);
            $projectdoc = $filename;
        }

        if ($request->file('risk_doc')) {
            $file2 = $request->file('risk_doc');
            $filename2 = md5($file->getClientOriginalName()) . uniqid() . '.' . $file2->getClientOriginalExtension();
            // $filename = 'Project_Doc'.'-'.$file->getClientOriginalName();
            $file2->move(public_path('storage/app/public/project_doc'), $filename2);
            $riskdoc = $filename2;
        }

        $namapm = Employee::where('email',$request->project_manager)->select('name')->pluck('name')->first();
        $jabatanpo = Employee::where('email',$request->project_manager)->select('position')->pluck('position')->first();
        $namapo = Employee::where('email',$request->project_owner)->select('name')->pluck('name')->first();
        $jabatanpm = Employee::where('email',$request->project_manager)->select('position')->pluck('position')->first();

        // dd($namapm,$namapo,$jabatanpm,$jabatanpo);

        $start = Carbon::createFromFormat('Y-m-d', $request->start_date);
        $end = Carbon::createFromFormat('Y-m-d', $request->end_date);

        $diff = $start->diffInDays($end,false);

        $duration = 1;

        for($i=1;$i<=$diff;$i++){
            $currday = $start->addDay();

            if($currday->isWeekday()){
                ++$duration;
            }
        }

        $pr = new Project();
        $pr->portofolio = $request->portofolio;
        $pr->step = 1;
        $pr->status = 'draft';        
        $pr->nama = Auth::user()->employee->name??'';
        $pr->jabatan = Auth::user()->employee->position??'';        
        $pr->project_name   = $request->project_name;
        $pr->series_id  = $request->series;
        $pr->grouptag = implode(',', $request->grouptag);
        $pr->project_budget   = $request->project_budget;
        $pr->investasi   = $request->investasi;
        $pr->cost   = $request->cost;
        $pr->end_date   = $request->end_date;
        $pr->start_date   = $request->start_date;
        $pr->duration   = $duration;
        $pr->project_description    = $request->project_description;
        $pr->team_member  = implode(',', $request->team_member);
        $pr->nama_po = $namapo;
        $pr->project_owner  = $request->project_owner;
        $pr->jabatan_po = 'Project Owner';
        $pr->nama_pm = $namapm;
        $pr->project_manager  = $request->project_manager;
        $pr->jabatan_pm = 'Project Manager';
        $pr->project_doc    = $projectdoc;
        $pr->risk_doc    = $riskdoc??'';
        $pr->created_by = Auth::id();
        // dd($pr);
        $pr->save();

        $positionbyproject = new Positionbyproject();
        $positionbyproject->project_id = $pr->id;
        $positionbyproject->email_pm = $pr->project_manager;
        $positionbyproject->email_po = $pr->project_owner;
        $positionbyproject->email_team_member = implode(',', $request->team_member);
        $positionbyproject->save();

        //create ganttask

        //get projectmanager id
        $idpm = Employee::where('email',$pr->project_manager)->first();
        $assigs[] = array('resourceId'=> 'tmp_'.$idpm->user_id);

        $ganttask = new GanttTask();
        $ganttask->project_id = $pr->id;
        $ganttask->code = $pr->full_number;
        $ganttask->name = $pr->project_name;
        $ganttask->status = 'STATUS_ACTIVE';
        $ganttask->level = 0;
        $ganttask->duration = $duration;
        $ganttask->description = $pr->project_name;
        $ganttask->start = $pr->start_date;
        $ganttask->end = $pr->end_date;
        $ganttask->collapsed = 0;
        $ganttask->canWrite = 1;
        $ganttask->canAdd = 1;
        $ganttask->canDelete = 1;
        $ganttask->canAddIssue = 1;
        $ganttask->assigs = json_encode($assigs);
        $ganttask->hasChild = 1;
        $ganttask->save();

        $step_gantt = GanttCode::OrderBy('sortable')->get();
        $sortable = 0;
        foreach($step_gantt as $step){
            $ganttask = new GanttTask();
            $ganttask->project_id = $pr->id;
            $ganttask->code = $step->name;
            $ganttask->name = ' ';
            $ganttask->status = 'STATUS_ACTIVE';
            $ganttask->level = 1;
            $ganttask->sortable = ++$sortable;
            $ganttask->duration = $duration;
            $ganttask->description = null;
            $ganttask->start = $pr->start_date;
            $ganttask->end = $pr->end_date;
            $ganttask->collapsed = 0;
            $ganttask->canWrite = 1;
            $ganttask->canAdd = 1;
            $ganttask->canDelete = 1;
            $ganttask->canAddIssue = 1;
            $ganttask->assigs = "[]";
            $ganttask->hasChild = 0;
            $ganttask->save();
        }
       

        $prtotask = Project::where('id',$pr->id)->update([
            'ganttask_id'    => $ganttask->id,
        ]);

        // send notif
        $status = 'Project has been made';

        
        //getusercreated
        $created = User::leftJoin('employees','users.id','employees.user_id')
        ->where('employees.user_id', Auth::id())
        ->select('users.id','employees.position_title','employees.name','users.email')
        ->first();

        //getmanager
        
        $users = User::leftJoin('employees','users.id','employees.user_id')
            ->whereIn('users.email', [$pr->project_owner,$pr->project_manager])
            ->select('users.id','employees.position_title','employees.name','users.email')
            ->get();

        $data['project_id'] = $pr->id;
        $data['project'] = $pr;
        $data['project_name'] = $pr->project_name;
        $data['status'] = $pr->status;
        $data['reason'] = $pr->status;
        $data['type'] = 'Staf';
        

        
        
        
        // notif user created
        $data['user'] = $created;
        $data['approval_id'] = $created->id;
        $data['project_nama'] = $created->name;
        $data['project_jabatan'] = $created->position_title;
        $this->sendNotif($data);

        // notif user manager
        if(!empty($users)){
            foreach($users as $user){
                $data['user'] = $user;
                $data['approval_id'] = $user->id;
                $data['project_nama'] = $user->name;
                $data['project_jabatan'] = $user->position_title;
                $this->sendNotif($data);
            }
            
        }

        // notif user member
        if(!empty($pr->team_member)){
            $members = User::leftJoin('employees','users.id','employees.user_id')
                ->whereIn('users.email', explode(',',$pr->team_member))           
                ->select('users.id','employees.name','users.email','employees.position')
                ->get();
            if(!empty($members)){
                foreach($members as $member){
                    $data['user'] = $member;
                    $data['approval_id'] = $member->id;
                    $data['project_nama'] = $member->name;
                    $data['project_jabatan'] = $member->position;
                    $this->sendNotif($data);
                }
            }
        }

        return redirect()->route('registeredproject')->with('success', 'Successfully Created');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $project = Project::findOrFail(decrypt($id));
        $employee = Employee::orderBy('name', 'asc')->get();
        $portofolio = Portofolio::get();
        $series = Series::get();
        $gt = GroupTag::get();
        return view('admin.manage_project.edit', compact('project', 'employee', 'portofolio', 'gt', 'series'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
       

        $oldproject_doc = $request->old_project_doc;
        $oldrisk_doc = $request->old_risk_doc;

        $namapm = Employee::where('email',$request->project_manager)->select('name')->pluck('name')->first();
        $jabatanpo = Employee::where('email',$request->project_manager)->select('position')->pluck('position')->first();
        $namapo = Employee::where('email',$request->project_owner)->select('name')->pluck('name')->first();
        $jabatanpm = Employee::where('email',$request->project_manager)->select('position')->pluck('position')->first();

        if ($request->file('project_doc')) {
            $file = $request->file('project_doc');
            $filename = md5($file->getClientOriginalName()) . uniqid() . '.' . $file->getClientOriginalExtension();
           
            $file->move(public_path('storage/app/public/project_doc'), $filename);
            $projectdoc = $filename;
        }

        if ($request->file('risk_doc')) {
            $file2 = $request->file('risk_doc');
            $filename2 = md5($file->getClientOriginalName()) . uniqid() . '.' . $file2->getClientOriginalExtension();
          
            $file2->move(public_path('storage/app/public/project_doc'), $filename2);
            $riskdoc = $filename2;
        }

        $start = Carbon::createFromFormat('Y-m-d', $request->start_date);
        $end = Carbon::createFromFormat('Y-m-d', $request->end_date);

        $diff = $start->diffInDays($end,false);

        $duration = 1;

        for($i=1;$i<=$diff;$i++){
            $currday = $start->addDay();

            if($currday->isWeekday()){
                ++$duration;
            }
        }

        if (!empty($request->project_doc)) {
            $pj = Project::findOrFail(decrypt($id))->update([
                'portofolio' => $request->portofolio,
                'project_name'   => $request->project_name,
                'series_id'  => $request->series,
                'grouptag' => implode(',', $request->grouptag),
                'project_budget'   => $request->project_budget,
                'investasi'   => $request->investasi,
                'cost'   => $request->cost,
                'end_date'   => $request->end_date,
                'start_date'   => $request->start_date,
                'duration'   => $duration,
                'project_description'    => $request->project_description,
                'nama_po'       => $namapo,
                'project_owner'  => $request->project_owner,
                'jabatan_po'    => 'Project Owner',
                'nama_pm'   => $namapm,
                'project_manager'  => $request->project_manager,
                'jabatan_pm'    => 'Project Manager',
                'team_member'   => implode(',', $request->team_member),
                'project_doc'    => $projectdoc,
                'risk_doc'    => $oldrisk_doc??'',
                'updated_by' => Auth::id(),
            ]);
        } elseif (!empty($request->risk_doc)) {
            $pj = Project::findOrFail(decrypt($id))->update([
                'portofolio' => $request->portofolio,
                'project_name'   => $request->project_name,
                'series_id'  => $request->series,
                'grouptag' => implode(',', $request->grouptag),
                'project_budget'   => $request->project_budget,
                'investasi'   => $request->investasi,
                'cost'   => $request->cost,
                'end_date'   => $request->end_date,
                'start_date'   => $request->start_date,
                'duration'   => $duration,
                'project_description'    => $request->project_description,
                'nama_po'       => $namapo,
                'project_owner'  => $request->project_owner,
                'jabatan_po'    => 'Project Owner',
                'nama_pm'   => $namapm,
                'project_manager'  => $request->project_manager,
                'jabatan_pm'    => 'Project Manager',
                'team_member'   => implode(',', $request->team_member),
                'project_doc'    => $oldproject_doc,
                'risk_doc'    => $riskdoc??'',
                'updated_by' => Auth::id(),
            ]);
        } else {
            $pj = Project::findOrFail(decrypt($id))->update([
                'portofolio' => $request->portofolio,
                'project_name'   => $request->project_name,
                'series_id'  => $request->series,
                'grouptag' => implode(',', $request->grouptag),
                'project_budget'   => $request->project_budget,
                'investasi'   => $request->investasi,
                'cost'   => $request->cost,
                'end_date'   => $request->end_date,
                'start_date'   => $request->start_date,
                'duration'   => $duration,
                'project_description'    => $request->project_description,
                'nama_po'       => $namapo,
                'project_owner'  => $request->project_owner,
                'jabatan_po'    => 'Project Owner',
                'nama_pm'   => $namapm,
                'project_manager'  => $request->project_manager,
                'jabatan_pm'    => 'Project Manager',
                'team_member'   => implode(',', $request->team_member),
                'project_doc'    => $oldproject_doc,
                'risk_doc'    => $oldrisk_doc??'',
                'updated_by' => Auth::id(),
            ]);
        }
        
        $proj = Project::where('id',decrypt($id))->first();

        $positionbyproject = Positionbyproject::where('project_id',decrypt($id))->update([
            'email_pm'  => $request->project_manager,
            'email_po'  => $request->project_owner,
            'email_team_member'  => implode(',', $request->team_member),
        ]);
       
        
        $idpm = Employee::where('email',$proj->project_manager)->first();

        // dd($idpm);
        
        $assigs[] = array('resourceId'=> 'tmp_'.$idpm->user_id);

        $ganttask = GanttTask::where('project_id',decrypt($id))->where('sortable',0)->first();
        $ganttask = GanttTask::where('id',$ganttask->id)->update([
            'code'  => $proj->full_number,
            'name'  => $proj->project_name,
            'status'    => 'STATUS_ACTIVE',
            'level' => 0,
            'duration'  => $proj->duration,
            'start' => $proj->start_date,
            'end' => $proj->end_date,
            'collapsed'  => 0,
            'canWrite'  => 1,
            'canAdd'    => 1,
            'canDelete' => 1,
            'canAddIssue'   => 1,
            'assigs'    => json_encode($assigs),
            'hasChild'  => 1,
        ]);
     

        return redirect()->route('registeredproject')->with('success', 'Successfully Updated');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */

    public function destroy($id)
    {
        $pj = Project::findOrFail(decrypt($id));
        $gant = GanttTask::where('project_id',decrypt($id))->forceDelete();
        $gantact = ActualGanttTask::where('project_id',decrypt($id))->forceDelete();
        $pj->forceDelete();
        return redirect()->back()->with('error', 'Project berhasil di Hapus');
    }

    public function gant($id)
    {
        $project = Project::findOrFail(decrypt($id));
        $employee = Employee::orderBy('nama', 'asc')->get();
        return view('admin.manage_project.gant', compact('id', 'project', 'employee'));
    }

    public function jgant($id)
    {
        $project = Project::findOrFail(decrypt($id));
        $employee = Employee::orderBy('nama', 'asc')->get();
        return view('admin.manage_project.jgantt', compact('id', 'project', 'employee'));
    }

    public function gant_store_wbs(Request $request)
    {
        $wbs = Wbs::findOrFail($request->wbs_id);
        $wbs->persentase_target = $request->persentase_target;
        $wbs->persentase_real = $request->persentase_real;
        $wbs->persentase_gap = $request->persentase_gap;
        $wbs->actual_start_date = !empty($request->actual_start_date) ? date('Y-m-d', strtotime($request->actual_start_date)) : null;
        $wbs->actual_finish_date = !empty($request->actual_finish_date) ? date('Y-m-d', strtotime($request->actual_finish_date)) : null;
        $wbs->actual_capex = $request->actual_capex;
        $wbs->actual_opex = $request->actual_opex;
        $wbs->assign_member = $request->assign_member;
        $wbs->task_status = $request->task_status;
        $wbs->task_health = $request->task_health;
        $wbs->save();

        return redirect()->back()->with('success', 'Successfully Updated');
    }

    public function Jquerygant($id)
    {
        $project = Project::findOrFail(decrypt($id));
        $tmp[] = array("id" => $id, "name" => $project->project_name, "progress" => 0, "progressByWorklog" => false, "relevance" => 0, "type" => "", "typeId" => "", "description" => "", "code" => "", "level" => 0, "status" => "STATUS_ACTIVE", "depends" => "", "canWrite" => true, "start" => strtotime($project->start_date)*1000, "duration" => $project->duration, 
                "end" => strtotime(date('Y-m-d H:i:s', strtotime($project->start_date.'+'.$project->duration.' days')))*1000, "startIsMilestone" => false, "endIsMilestone" => false, "collapsed" => false, "assigs" => [], "hasChild" => true);
        $i = 1;
        $level = $is_level = 1;
        $tmp_datas = $project->Wbs;
        foreach($tmp_datas as $wbs){
           
            if($wbs->id == $project->wbs_id) $id = 1;
            else $id = ++$i;
            $cek_child = $tmp_datas->where('parent',$wbs->id)->first();

            $has_child = false;
            if(!empty($cek_child)) {
                $has_child = true;
            }

            if(!empty($cek_child)){
                $is_level = $level+1;
            }else{
                $is_level++;
            }
            $ids[$wbs->id] = $id; 

            $tmp[] = array("id" => $id, "name" => $wbs->text, "progress" => 0, "progressByWorklog" => false, "relevance" => 0, "type" => "", "typeId" => "", "description" => "", "code" => "", "level" => (int)$is_level, "status" => "STATUS_ACTIVE", "depends" => "", "canWrite" => true, "start" => strtotime($wbs->start_date)*1000, "duration" => $wbs->duration, 
                "end" => strtotime(date('Y-m-d H:i:s', strtotime($wbs->start_date.'+'.$wbs->duration.' days')))*1000, "startIsMilestone" => false, "endIsMilestone" => false, "collapsed" => false, "assigs" => [], "hasChild" => $has_child);
        }

        $wbs_datas = json_encode(array("tasks" => $tmp, "selectedRow" => 2,"deletedTaskIds"=>array(),
            "resources"=>[],"roles"=>[],"canWrite" => true, "canDelete" => false, "canWriteOnParent" => true));
        $employee = Employee::orderBy('nama', 'asc')->get();
        return view('admin.manage_project.jquery_gantt', compact('id', 'project', 'employee','wbs_datas'));

    }

    public function Jquerygant_store_wbs(Request $request)
    {
        $wbs = Wbs::findOrFail($request->wbs_id);
        $wbs->persentase_target = $request->persentase_target;
        $wbs->persentase_real = $request->persentase_real;
        $wbs->persentase_gap = $request->persentase_gap;
        $wbs->actual_start_date = !empty($request->actual_start_date) ? date('Y-m-d', strtotime($request->actual_start_date)) : null;
        $wbs->actual_finish_date = !empty($request->actual_finish_date) ? date('Y-m-d', strtotime($request->actual_finish_date)) : null;
        $wbs->actual_capex = $request->actual_capex;
        $wbs->actual_opex = $request->actual_opex;
        $wbs->assign_member = $request->assign_member;
        $wbs->task_status = $request->task_status;
        $wbs->task_health = $request->task_health;
        $wbs->save();

        return redirect()->back()->with('success', 'Successfully Updated');
    }

    public function actual_gantt($id)
    {
        
       

        $oldRecords = GanttTask::where('project_id','=',decrypt($id))->get();
        $pr = Project::findorfail(decrypt($id));
        
        if(!empty($oldRecords)){
            ActualGanttTask::where('project_id','=',decrypt($id))->delete();
            foreach($oldRecords as $oldRecord){
                $newRecord = $oldRecord->toArray();
           
                $newRecord['id'] = $oldRecord->id;
                $newRecord['task_budget'] = NULL;
    
                $new = ActualGanttTask::updateOrCreate(['id'=>$newRecord['id']],$newRecord);
                
                unset($newRecord);
            }
            $status = Project::where('id',decrypt($id))->update([
                'status'    => 'Started',
            ]);

        }



       //getusercreated
       $created = User::leftJoin('employees','users.id','employees.user_id')
       ->where('employees.user_id', Auth::id())
       ->select('users.id','employees.position_title','employees.name','users.email')
       ->first();

        //getmanager
        
        $users = User::leftJoin('employees','users.id','employees.user_id')
            ->whereIn('users.email', [$pr->project_owner,$pr->project_manager])
            ->select('users.id','employees.name','users.email')
            ->get();

        $data['project_id'] = $pr->id;
        $data['project'] = $pr;
        $data['project_name'] = $pr->project_name;
        // $data['status'] = $pr->status;
        $data['status'] = 'Started';
        $data['reason'] = $pr->status;
        $data['type'] = 'Staf';
     


        
        // notif user created
        $data['user'] = $created;
        $data['approval_id'] = $created->id;
        $data['project_nama'] = $created->name;
        $data['project_jabatan'] = $created->jabatan;
        $this->sendNotif($data);

        // notif user manager
        if(!empty($users)){
            foreach($users as $user){
                $data['user'] = $user;
                $data['approval_id'] = $user->id;
                $data['project_nama'] = $user->name;
                $data['project_jabatan'] = $user->jabatan;
                $this->sendNotif($data);
            }
            
        }

        // notif user member
        if(!empty($pr->team_member)){
            $members = User::leftJoin('employees','users.id','employees.user_id')
                ->whereIn('users.email', explode(',',$pr->team_member))           
                ->select('users.id','employees.name','users.email')
                ->get();
            if(!empty($members)){
                foreach($members as $member){
                    $data['user'] = $member;
                    $data['approval_id'] = $member->id;
                    $data['project_nama'] = $member->name;
                    $data['project_jabatan'] = 'Team Member';
                    $this->sendNotif($data);
                }
            }
        }

        return redirect()->back()->with('success', 'Project Started');

    }

    public function sendNotif($data, $notif_email=''){


        $approval = new Approval;
        $approval->project_id   = $data['project_id'];
        $approval->status       = $data['status'];
        $approval->reason       = $data['reason'];
        $approval->approval_by  = $data['approval_id'];
        $approval->approval_name    = $data['project_nama'];
        $approval->approval_jabatan = $data['project_jabatan'];
        $approval->save();
        
        Notification::send($data['user'], new ApprovalNotification($data['project'],$data['project_name'], $data['status'], $data['type'],$data['user']));
        
    }

    

}
