<?php

use App\Http\Controllers\AjaxController;
use App\Http\Controllers\ApprovalController;
use App\Http\Controllers\BranchController;
use App\Http\Controllers\CardTaskController;
use App\Http\Controllers\CountryController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\GanttCodeController;
use App\Http\Controllers\GanttController;
use App\Http\Controllers\GroupTagController;
use App\Http\Controllers\KanbanStatusController;
use App\Http\Controllers\PortofolioController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\ProjectController;
use App\Http\Controllers\ProjectTrackingController;
use App\Http\Controllers\RoleController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\WbsController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Auth::routes(['register' => false, 'verify' => true]);

Route::get('/', function () {
    return redirect()->route('login');
});

Route::post('logout', [UserController::class, 'logout'])->name('logout');

Route::group(['middleware' => ['auth','XssSanitizer','verified']], function () {
 
    //dashboard
    Route::match(['GET', 'POST'],'/dashboard', [DashboardController::class, 'index'])->name('dashboard');
    Route::get('/dashboard/see-all-progress',[DashboardController::class,'seeallProgress'])->name('seeallProgress');
    Route::get('/dashboard/see-all-cost',[DashboardController::class,'seeallCost'])->name('seeallCost');

    Route::match(['GET', 'POST'],'/dashboard/downloaddashboard',[DashboardController::class,'downloaddashboard'])->name('downloaddashboard');

    Route::get('/mark-all-as-read', [DashboardController::class, 'markAllAsRead'])->name('project.markAllAsRead');
    Route::get('/notification/see-all',[DashboardController::class,'seeallnotif'])->name('seeallnotif');

    //dashboard employee
    Route::match(['GET', 'POST'],'/dashboard/employee', [DashboardController::class, 'dashboard_employee'])->name('dashboard_employee');
    //kanban status

    //Project

    Route::match(['GET','POST'],'/project', [ProjectController::class, 'index'])->name('project.index');
    Route::match(['GET','POST'],'/project/registeredproject', [ProjectController::class, 'registeredproject'])->name('registeredproject');
    Route::get('/project/download_pdf/{id}', [ProjectController::class, 'downloadpdf'])->name('downloadpdf');
    Route::get('/project/create', [ProjectController::class, 'create'])->name('project.create');
    Route::post('/project/store', [ProjectController::class, 'store'])->name('project.store');
    Route::get('/project/edit/{id}', [ProjectController::class, 'edit'])->name('project.edit');
    Route::post('/project/update/{id}', [ProjectController::class, 'update'])->name('project.update');
    Route::post('/project/delete/{id}', [ProjectController::class, 'destroy'])->name('project.destroy');



    //approval
    Route::post('/project/needapprovalmanager/{id}', [ApprovalController::class, 'needapprovalmanager'])->name('project.needapprovalmanager');
    Route::post('/project/needapprovalvp/{id}', [ApprovalController::class, 'needapprovalvp'])->name('project.needapprovalvp');
    Route::post('/project/approvedvp/{id}', [ApprovalController::class, 'approvedvp'])->name('project.approvedvp');
    Route::post('/project/rejectedbymgr/{id}', [ApprovalController::class, 'rejectedbymgr'])->name('project.rejectedbymgr');
    Route::post('/project/rejectedbyvp/{id}', [ApprovalController::class, 'rejectedbyvp'])->name('project.rejectedbyvp');
    //getactual project
    Route::get('/project/actual-gantt/{id}',[ProjectController::class,'actual_gantt'])->name('actual_gantt');

    //gantt

    Route::get('/gantchart/{id}',[GanttController::class,'gantt'])->name('gantchart');
    Route::get('/gantchartstarted/{id}',[GanttController::class,'gantchartstarted'])->name('gantchartstarted');
    Route::post('/gantchart',[GanttController::class,'store'])->name('gantchart.store');
    Route::get('/gantchart-aktual/{id}',[GanttController::class,'ganttAktualisasi'])->name('gantchart.aktual');
    Route::post('/gantchart-aktual',[GanttController::class,'storeAktual'])->name('gantchart.storeAktual');
    //iframe
   
    // aktual v2
    Route::get('/gantchart-aktual-2/{id}',[GanttController::class,'ganttAktualisasi_v2'])->name('gantchart.aktual.v2');

    
    //Profile
    Route::get('/profile/{id}',[ProfileController::class,'index'])->name('profile.index');
    Route::post('/profile/update', [ProfileController::class, 'update'])->name('profile.update');
    Route::post('/profile/change_password/{id}',[ProfileController::class,'change_password'])->name('profile.change_password');

    //CardTask
    Route::get('/todo',[CardTaskController::class,'index'])->name('todo.index');
    Route::post('/todo/store',[CardTaskController::class,'store'])->name('todo.store');
    Route::post('/todo/update',[CardTaskController::class,'update'])->name('todo.update');
    Route::get('/todo/softdelete/{id}',[CardTaskController::class,'SoftDelete'])->name('todo.softdelete');
    Route::get('/todo/recycle',[CardTaskController::class,'recycle'])->name('todo.recycle');
    Route::get('/todo/restore/{id}',[CardTaskController::class,'restore'])->name('todo.restore');
    Route::get('/todo/destroy/{id}',[CardTaskController::class,'destroy'])->name('todo.destroy');
    Route::post('/todo/update-task',[CardTaskController::class,'updateTask'])->name('todo.updatetask');
    Route::post('/todo/update-status',[CardTaskController::class,'updateStatus'])->name('todo.update-status');

    //master data
    Route::get('/portofolio', [PortofolioController::class, 'index'])->name('p.index');
    Route::post('/portofolio/store', [PortofolioController::class, 'store'])->name('p.store');
    Route::post('/portofolio/update', [PortofolioController::class, 'update'])->name('p.update');
    Route::post('/portofolio/softdelete/{id}', [PortofolioController::class, 'SoftDelete'])->name('p.softdelete');

    //branch
    Route::get('/branch', [BranchController::class, 'index'])->name('branch.index');
    Route::post('/branch/store', [BranchController::class, 'store'])->name('branch.store');
    Route::post('/branch/update', [BranchController::class, 'update'])->name('branch.update');
    Route::post('/branch/delete/{id}', [BranchController::class, 'destroy'])->name('branch.delete');

    //country
    Route::get('/country', [CountryController::class, 'index'])->name('country.index');
    Route::post('/country/store', [CountryController::class, 'store'])->name('country.store');
    Route::post('/country/update', [CountryController::class, 'update'])->name('country.update');
    Route::post('/country/delete/{id}', [CountryController::class, 'destroy'])->name('country.delete');

    Route::get('/kanban-status', [KanbanStatusController::class, 'index'])->name('kanban.index');
    Route::post('/kanban-status/store', [KanbanStatusController::class, 'store'])->name('kanban.store');
    Route::post('/kanban-status/update', [KanbanStatusController::class, 'update'])->name('kanban.update');
    Route::post('/kanban-status/softdelete/{id}', [KanbanStatusController::class, 'SoftDelete'])->name('kanban.softdelete');

    Route::get('/gantt-code', [GanttCodeController::class, 'index'])->name('ganttcode.index');
    Route::post('/gantt-code/store', [GanttCodeController::class, 'store'])->name('ganttcode.store');
    Route::post('/gantt-code/update', [GanttCodeController::class, 'update'])->name('ganttcode.update');


    Route::get('/group-tag', [GroupTagController::class, 'index'])->name('gt.index');
    Route::post('/group-tag/store', [GroupTagController::class, 'store'])->name('gt.store');
    Route::post('/group-tag/update', [GroupTagController::class, 'update'])->name('gt.update');
    Route::post('/group-tag/softdelete/{id}', [GroupTagController::class, 'SoftDelete'])->name('gt.softdelete');

    Route::get('/project-tracking/gantt/{id}', [ProjectTrackingController::class, 'index'])->name('gantt');

    Route::post('/ajax/get_group_tag_by_portofolio_id', [AjaxController::class, 'get_group_tag_by_portofolio_id'])->name('get_group_tag_by_portofolio_id');

    //WBS
    Route::get('/wbs',[WbsController::class,'index'])->name('wbs.index');
    Route::get('/wbs/detil/{id}',[WbsController::class,'detilproject'])->name('wbs.detil');
    Route::get('/wbs/edit-plan/{id}',[WbsController::class,'editplan'])->name('wbs.editplan');
    Route::post('/wbs/update-plan/',[WbsController::class,'updateplan'])->name('wbs.updateplan');

    //pdf download
    Route::get('/wbs/download-planning/{id}',[WbsController::class,'downloadwbsrencana'])->name('wbs.downloadwbsrencana');
    Route::get('/wbs/download-aktual/{id}',[WbsController::class,'downloadwbsaktual'])->name('wbs.downloadwbsaktual');

    //donlot excel
    Route::get('wbs/download-xls/{id}',[WbsController::class,'downloadwbsXls'])->name('wbs.downloadwbsXls');
    

    //User
    Route::resource('roles', RoleController::class);
    Route::get('roles/destroy/{id}',[RoleController::class,'destroy'])->name('delete.roles');
    Route::get('/user-management',[UserController::class,'index'])->name('user.index');
    Route::post('/user-management/store',[UserController::class,'store'])->name('user.store');    
    Route::get('/user-management/edit/{id}',[UserController::class,'edit'])->name('user.edit');
    Route::post('/user-management/update/{id}', [UserController::class, 'update'])->name('user.update');
    Route::post('/user-management/changeStatus/{id}', [UserController::class, 'changeStatus'])->name('user.change');

    
});


